Skip to contents

The Generalized Extreme Value (GEV) distribution unifies the three extreme value distributions — Gumbel (Type I), Fréchet (Type II), and Reverse Weibull (Type III) — into a single family, parameterized by location, scale, and a shape parameter that determines which type applies.

Usage

dgev(x, loc = 0, scale = 1, shape = 0, log = FALSE)

pgev(q, loc = 0, scale = 1, shape = 0, lower.tail = TRUE, log.p = FALSE)

qgev(p, loc = 0, scale = 1, shape = 0, lower.tail = TRUE, log.p = FALSE)

rgev(n, loc = 0, scale = 1, shape = 0)

Arguments

x, q

vector of quantiles.

loc, scale, shape

location, scale and shape parameters; the shape argument cannot be a vector (must have length one).

log, log.p

logical; if TRUE, probabilities p are given as log(p) and the density is returned on the log scale.

lower.tail

logical; if TRUE (default), probabilities are P[X <= x], otherwise, P[X > x].

p

vector of probabilities.

n

number of observations.

Value

dgev() gives the density function, pgev() gives the distribution function, qgev() gives the quantile function, and rgev() generates random deviates.

Details

Density function, distribution function, quantile function and random generation for the generalized extreme value (GEV) distribution with location, scale and shape parameters.

The GEV distribution function with parameters \(`loc` = a\), \(`scale` = b\) and \(`shape` = s\) is $$G(z) = \exp\left[-\{1+s(z-a)/b\}^{-1/s}\right]$$ for \(1+s(z-a)/b > 0\), where \(b > 0\). If \(s = 0\) the distribution is defined by continuity. If \(1+s(z-a)/b \leq 0\), the value \(z\) is either greater than the upper end point (if \(s < 0\)), or less than the lower end point (if \(s > 0\)).

The parametric form of the GEV encompasses that of the Gumbel, Frechet and reverse Weibull distributions, which are obtained for \(s = 0\), \(s > 0\) and \(s < 0\) respectively. It was first introduced by Jenkinson (1955).

Note

Based on code by Alec Stephenson previously published in the evd package, adapted to conform to package standards.

References

Jenkinson, A. F. (1955) The frequency distribution of the annual maximum (or minimum) of meteorological elements. Quart. J. R. Met. Soc., 81, 158–171.

See also

distributions-overview; evd::fgev() for fitting the GEV to data

Examples


dgev(2:4, 1, 0.5, 0.8)
#> [1] 0.17210639 0.06706381 0.03428205
pgev(2:4, 1, 0.5, 0.8)
#> [1] 0.7386812 0.8467772 0.8948490
qgev(seq(0.9, 0.6, -0.1), 2, 0.5, 0.8)
#> [1] 5.157141 3.449973 2.800811 2.444700
rgev(6, 1, 0.5, 0.8)
#> [1] 2.1900924 1.1968316 0.9958415 0.7560799 7.0426032 3.8921888
p <- (1:9)/10
pgev(qgev(p, 1, 2, 0.8), 1, 2, 0.8)
#> [1] 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9
## [1] 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9