The plot method visualizes pairwise comparisons from a PostHocTest object
using dot plots.
Each component of x is plotted separately, showing estimated differences
along with confidence intervals. A vertical reference line at zero is added.
Usage
# S3 method for class 'PostHocTest'
plot(x, ...)Arguments
- x
an object of class
"PostHocTest", typically returned bypostHocTest().- ...
additional graphical parameters passed to
pharos::plotDot()and base plotting functions.
Details
For each factor in x, a dot plot is produced displaying pairwise
differences in means and their confidence intervals. The confidence level
is taken from the "conf.level" attribute of x.
See also
Other test.posthoc:
conoverTest(),
dscfTest(),
dunnTest(),
dunnettTest(),
gamesHowellTest(),
nemenyiTest(),
postHoc,
scheffeTest(),
signifDiff(),
steelTest()