Starting with a response variable that obtains different confidence intervals (CI) when calculated with different explanatory variables, all the values of the response variable should be added up. This function returns the CI for the sum.
Value
A named numeric vector with elements:
estpoint estimate,
sum(x).lcilower confidence interval bound.
uciupper confidence interval bound.
See also
Other ci.location:
meanCI(),
meanCIn(),
meanDiffCI(),
medianCI(),
quantileCI()